{% load i18n %}

{% if request.user.is_authenticated %}
    <li class="navbar-text">
        {% blocktrans with username=request.user.username %}
            Welcome <strong>{{ request.username }}</strong>
        {% endblocktrans %}
    </li>
    <li>
        <a href="{% url "account-logout" %}">{% trans "Logout" %}</a>
    </li>
{% else %}
    <li>
        <a href="{% url "socialauth_begin" "facebook" %}">{% trans "Login with Facebook" %}</a>
    </li>
{% endif %}