{% load i18n %}
<!DOCTYPE html>
<html lang="en">
<head>
    <title>{% trans "Carrots" %}</title>
</head>
<body>
<div class="container">
    <div class="header">
        {% block header %}
            {% include "account/header.html" %}
        {% endblock %}
    </div>
    <div>
        {% block content %}

        {% endblock %}
    </div>
</div>
</body>
</html>